<?php
defined( 'ABSPATH' ) or die( 'Nope, not accessing this' );
/**
 * Plugin Name: RJCardenas Caldera Forms Field Validator 
 * Description: Procesador personalizado para Caldera Forms. Limita la seleccion de opciones a un máximo de 3
 * Version:     1.01
 * Author:      Rolando Cárdenas
 * Author URI:  https://www.rjcardenas.com/
 * License:     GPL2
 * Text Domain: rjc_cf_validator
 */
add_filter('caldera_forms_get_form_processors', 'rjcardenas_cf_validator_processor');

/**
 * Agrega una validacion personalizada a Caldera Forms
 * @uses 'rjcardenas_cf_validator_processor'
 * @param array $processors Processor configs
 * @return array
 */
function rjcardenas_cf_validator_processor($processors){
  $processors['rjcardenas_cf_validator'] = array(
    'name' => __('Máximo tres opciones', 'rjc_cf_validator' ),
    'description' => 'Limita las opciones en checkbosx y select a un máximo de 3',
    'pre_processor' => 'rjcardenas_validator',
    'template' => dirname(__FILE__) . '/config.php'
  );
  return $processors;
}

/**
 * Run field validation
 *
 * @param array $config Processor config
 * @param array $form Form config
 *
 * @return array|void Error array if needed, else void.
 */
function rjcardenas_validator( array $config, array $form ){
  $data = new Caldera_Forms_Processor_Get_Data( $config, $form, rjcardenas_cf_validator_fields() );
  $value = $data->get_value( 'field-to-validate' );
  if( false == rjcardenas_cf_validator_is_valid( $value ) ){ 
    //no pasa la validacion, avisamos del error
    $fields = $data->get_fields();
    $field_id = $fields[ 'field-to-validate' ][ 'config_field' ];
    $field = $form[ 'fields' ][ $field_id ];
    $label = $field[ 'label' ];
    return array(
      'type' => 'error',
      'note' => sprintf( 'Por favor corrija %s', $label ),
      'fields' => array(
        $field_id => __( 'Solo se permiten 3 opciones máximo', 'rjc_cf_validator' )
      )
    );
  }
  //Si todo está bien no devolvemos nada
}

/**
 * funciones que comprueba los valores
 * @return bool
 */
function rjcardenas_cf_validator_is_valid( $value ){
  $total=explode(', ', $value);
  return count($total)<=3;
}

/**
 * Processor fields
 *
 * @return array
 */
function rjcardenas_cf_validator_fields(){
  return array(
    array(
      'id' => 'field-to-validate',
      'type' => 'text',
      'required' => true,
      'magic' => true,
      'label' => __( 'Campo a validar.', 'rjc_cf_validator' )
    ),
  );
}